@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "magit-todos" "1.8.1"
+(define-package "magit-todos" "20250928.1611"
   "Show source file TODOs in Magit."
   '((emacs     "26.1")
     (async     "1.9.2")
@@ -10,9 +10,9 @@
     (pcre2el   "1.8")
     (s         "1.12.0")
     (transient "0.2.0"))
-  :url "https://github.com/alphapapa/magit-todos"
-  :commit "cebcbb8fed2ffcca6c42a9e0338fe129aad4dbc9"
-  :revdesc "v1.8.1-0-gcebcbb8fed2f"
+  :url "http://github.com/alphapapa/magit-todos"
+  :commit "7294a95580bddf7232f2d205efae312dc24c5f61"
+  :revdesc "7294a95580bd"
   :keywords '("magit" "vc")
   :authors '(("Adam Porter" . "adam@alphapapa.net"))
   :maintainers '(("Adam Porter" . "adam@alphapapa.net")))
